@@ -2,7 +2,7 @@
 from .common import ExtendedEnum
 
 
-class MonitorType(ExtendedEnum, str):
+class MonitorType(ExtendedEnum):
     """Type of monitoring data"""
 
     NUMERIC = "numeric"
